@@ -112,6 +112,10 @@ def pkgs_handling_appstream_modaliases(modaliaslist):
 def check_packages_file(pkghash, fileref, modaliaslist):
     line = fileref.readline()
     while line:
+        # Skip lines starting with comment character
+        if 0 == line.find('#'):
+            line = fileref.readline()
+            continue
         header, sep, packagename = line.strip().partition(": ")
         header, sep, modaliases = fileref.readline().strip().partition(": ")
         blank = fileref.readline()
